@@ -1,7 +1,10 @@
+#define USE_FC_LEN_T 1
+#include <stddef.h>
 #include <R.h>
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <limits.h>
 
 static int min_JM (int *, int *);
 static int max_JM (int *, int *);
@@ -94,7 +97,7 @@ svd_JM (double *mat, int *n, int *p, double *u, double *d, double *v)
     b = 4 * mm * mm + 4 * mm;
     ilwork = 3 * mm * mm + max_JM(&a, &b);
     if (ilwork > INT_MAX)
-	error("svd on %d x %d exceeds Fortran indexing limits");
+	error("svd on %lu x %lu exceeds Fortran indexing limits", nn, pp);
 
     work = Calloc (ilwork, double);
     iwork = Calloc (iwork_size, int);
@@ -106,7 +109,7 @@ svd_JM (double *mat, int *n, int *p, double *u, double *d, double *v)
 
     lwork = ilwork;
     F77_CALL (dgesdd) (&jobz, n, p, mat1, n, d, u1, n, v1, p, work,
-		       &lwork, iwork, &info);
+		       &lwork, iwork, &info FCONE);
 
     transpose_mat_JM (u1, n, n, u);
     transpose_mat_JM (v1, p, p, v);
@@ -174,7 +177,7 @@ mmult_JM (double *A, int n, int p, double *B, int q, int r, double *C)
 	K = p;
 	N = r;
 	F77_CALL (dgemm) (&transA, &transB, &N, &M, &K, &alpha, B, &N,
-			  A, &K, &beta, C, &N);
+			  A, &K, &beta, C, &N FCONE FCONE);
     }
 }
 
